from test.api.bookmark.test_bookmark import TestBookmark
from test.api.compatibility.test_compatibility import TestCompatibility
from test.api.document.test_append_document import TestAppendDocument
from test.api.document.test_classification import TestClassification
from test.api.document.test_comment import TestComment
from test.api.document.test_compare_document import TestCompareDocument
from test.api.document.test_convert_document import TestConvertDocument
from test.api.document.test_document import TestDocument
from test.api.document.test_document_statistics import TestDocumentStatistics
from test.api.document.test_document_with_format import TestDocumentWithFormat
from test.api.document.test_load_web_document import TestLoadWebDocument
from test.api.document.test_revisions import TestRevisions
from test.api.document.test_split_document_to_format import TestSplitDocumentToFormat
from test.api.document_properties.test_document_properties import TestDocumentProperties
from test.api.document_protection.test_document_protection import TestDocumentProtection
from test.api.drawing.test_drawing_objects import TestDrawingObjects
from test.api.field.test_field import TestField
from test.api.field.test_form_field import TestFormField
from test.api.font.test_font import TestFont
from test.api.footnote.test_footnote import TestFootnote
from test.api.header_footer.test_header_footer import TestHeaderFooter
from test.api.hyperlink.test_hyperlink import TestHyperlink
from test.api.lists.test_lists import TestLists
from test.api.macros.test_macros import TestMacros
from test.api.mail_merge.test_execute_mail_merge import TestExecuteMailMerge
from test.api.mail_merge.test_execute_template import TestExecuteTemplate
from test.api.mail_merge.test_mail_merge_fileds import TestMailMergeFileds
from test.api.math_object.test_math_object import TestMathObject
from test.api.page_setup.test_page_setup import TestPageSetup
from test.api.paragraph.test_paragraph import TestParagraph
from test.api.range.test_range import TestRange
from test.api.report.test_build_report import TestBuildReport
from test.api.run.test_run import TestRun
from test.api.sections.test_section import TestSection
from test.api.storage.test_file import TestFile
from test.api.storage.test_folder import TestFolder
from test.api.styles.test_styles import TestStyles
from test.api.table.test_table import TestTable
from test.api.table.test_table_border import TestTableBorder
from test.api.text.test_text import TestText
from test.api.watermark.test_watermark import TestWatermark
from test.test_url_encode import TestUrlEncode
from test.test_readme import TestReadme
from test.test_batch import TestBatch
from test.test_examples import TestExamples