from asposewordscloud.models.requests.base_request_object import BaseRequestObject
from asposewordscloud.models.requests.accept_all_revisions_request import AcceptAllRevisionsRequest
from asposewordscloud.models.requests.accept_all_revisions_online_request import AcceptAllRevisionsOnlineRequest
from asposewordscloud.models.requests.append_document_request import AppendDocumentRequest
from asposewordscloud.models.requests.append_document_online_request import AppendDocumentOnlineRequest
from asposewordscloud.models.requests.apply_style_to_document_element_request import ApplyStyleToDocumentElementRequest
from asposewordscloud.models.requests.apply_style_to_document_element_online_request import ApplyStyleToDocumentElementOnlineRequest
from asposewordscloud.models.requests.build_report_request import BuildReportRequest
from asposewordscloud.models.requests.build_report_online_request import BuildReportOnlineRequest
from asposewordscloud.models.requests.classify_request import ClassifyRequest
from asposewordscloud.models.requests.classify_document_request import ClassifyDocumentRequest
from asposewordscloud.models.requests.classify_document_online_request import ClassifyDocumentOnlineRequest
from asposewordscloud.models.requests.compare_document_request import CompareDocumentRequest
from asposewordscloud.models.requests.compare_document_online_request import CompareDocumentOnlineRequest
from asposewordscloud.models.requests.convert_document_request import ConvertDocumentRequest
from asposewordscloud.models.requests.copy_file_request import CopyFileRequest
from asposewordscloud.models.requests.copy_folder_request import CopyFolderRequest
from asposewordscloud.models.requests.copy_style_request import CopyStyleRequest
from asposewordscloud.models.requests.copy_style_online_request import CopyStyleOnlineRequest
from asposewordscloud.models.requests.create_document_request import CreateDocumentRequest
from asposewordscloud.models.requests.create_folder_request import CreateFolderRequest
from asposewordscloud.models.requests.create_or_update_document_property_request import CreateOrUpdateDocumentPropertyRequest
from asposewordscloud.models.requests.create_or_update_document_property_online_request import CreateOrUpdateDocumentPropertyOnlineRequest
from asposewordscloud.models.requests.delete_all_paragraph_tab_stops_request import DeleteAllParagraphTabStopsRequest
from asposewordscloud.models.requests.delete_all_paragraph_tab_stops_online_request import DeleteAllParagraphTabStopsOnlineRequest
from asposewordscloud.models.requests.delete_border_request import DeleteBorderRequest
from asposewordscloud.models.requests.delete_border_online_request import DeleteBorderOnlineRequest
from asposewordscloud.models.requests.delete_borders_request import DeleteBordersRequest
from asposewordscloud.models.requests.delete_borders_online_request import DeleteBordersOnlineRequest
from asposewordscloud.models.requests.delete_comment_request import DeleteCommentRequest
from asposewordscloud.models.requests.delete_comment_online_request import DeleteCommentOnlineRequest
from asposewordscloud.models.requests.delete_comments_request import DeleteCommentsRequest
from asposewordscloud.models.requests.delete_comments_online_request import DeleteCommentsOnlineRequest
from asposewordscloud.models.requests.delete_document_property_request import DeleteDocumentPropertyRequest
from asposewordscloud.models.requests.delete_document_property_online_request import DeleteDocumentPropertyOnlineRequest
from asposewordscloud.models.requests.delete_drawing_object_request import DeleteDrawingObjectRequest
from asposewordscloud.models.requests.delete_drawing_object_online_request import DeleteDrawingObjectOnlineRequest
from asposewordscloud.models.requests.delete_field_request import DeleteFieldRequest
from asposewordscloud.models.requests.delete_field_online_request import DeleteFieldOnlineRequest
from asposewordscloud.models.requests.delete_fields_request import DeleteFieldsRequest
from asposewordscloud.models.requests.delete_fields_online_request import DeleteFieldsOnlineRequest
from asposewordscloud.models.requests.delete_file_request import DeleteFileRequest
from asposewordscloud.models.requests.delete_folder_request import DeleteFolderRequest
from asposewordscloud.models.requests.delete_footnote_request import DeleteFootnoteRequest
from asposewordscloud.models.requests.delete_footnote_online_request import DeleteFootnoteOnlineRequest
from asposewordscloud.models.requests.delete_form_field_request import DeleteFormFieldRequest
from asposewordscloud.models.requests.delete_form_field_online_request import DeleteFormFieldOnlineRequest
from asposewordscloud.models.requests.delete_header_footer_request import DeleteHeaderFooterRequest
from asposewordscloud.models.requests.delete_header_footer_online_request import DeleteHeaderFooterOnlineRequest
from asposewordscloud.models.requests.delete_headers_footers_request import DeleteHeadersFootersRequest
from asposewordscloud.models.requests.delete_headers_footers_online_request import DeleteHeadersFootersOnlineRequest
from asposewordscloud.models.requests.delete_macros_request import DeleteMacrosRequest
from asposewordscloud.models.requests.delete_macros_online_request import DeleteMacrosOnlineRequest
from asposewordscloud.models.requests.delete_office_math_object_request import DeleteOfficeMathObjectRequest
from asposewordscloud.models.requests.delete_office_math_object_online_request import DeleteOfficeMathObjectOnlineRequest
from asposewordscloud.models.requests.delete_paragraph_request import DeleteParagraphRequest
from asposewordscloud.models.requests.delete_paragraph_list_format_request import DeleteParagraphListFormatRequest
from asposewordscloud.models.requests.delete_paragraph_list_format_online_request import DeleteParagraphListFormatOnlineRequest
from asposewordscloud.models.requests.delete_paragraph_online_request import DeleteParagraphOnlineRequest
from asposewordscloud.models.requests.delete_paragraph_tab_stop_request import DeleteParagraphTabStopRequest
from asposewordscloud.models.requests.delete_paragraph_tab_stop_online_request import DeleteParagraphTabStopOnlineRequest
from asposewordscloud.models.requests.delete_run_request import DeleteRunRequest
from asposewordscloud.models.requests.delete_run_online_request import DeleteRunOnlineRequest
from asposewordscloud.models.requests.delete_section_request import DeleteSectionRequest
from asposewordscloud.models.requests.delete_section_online_request import DeleteSectionOnlineRequest
from asposewordscloud.models.requests.delete_table_request import DeleteTableRequest
from asposewordscloud.models.requests.delete_table_cell_request import DeleteTableCellRequest
from asposewordscloud.models.requests.delete_table_cell_online_request import DeleteTableCellOnlineRequest
from asposewordscloud.models.requests.delete_table_online_request import DeleteTableOnlineRequest
from asposewordscloud.models.requests.delete_table_row_request import DeleteTableRowRequest
from asposewordscloud.models.requests.delete_table_row_online_request import DeleteTableRowOnlineRequest
from asposewordscloud.models.requests.delete_watermark_request import DeleteWatermarkRequest
from asposewordscloud.models.requests.delete_watermark_online_request import DeleteWatermarkOnlineRequest
from asposewordscloud.models.requests.download_file_request import DownloadFileRequest
from asposewordscloud.models.requests.execute_mail_merge_request import ExecuteMailMergeRequest
from asposewordscloud.models.requests.execute_mail_merge_online_request import ExecuteMailMergeOnlineRequest
from asposewordscloud.models.requests.get_available_fonts_request import GetAvailableFontsRequest
from asposewordscloud.models.requests.get_bookmark_by_name_request import GetBookmarkByNameRequest
from asposewordscloud.models.requests.get_bookmark_by_name_online_request import GetBookmarkByNameOnlineRequest
from asposewordscloud.models.requests.get_bookmarks_request import GetBookmarksRequest
from asposewordscloud.models.requests.get_bookmarks_online_request import GetBookmarksOnlineRequest
from asposewordscloud.models.requests.get_border_request import GetBorderRequest
from asposewordscloud.models.requests.get_border_online_request import GetBorderOnlineRequest
from asposewordscloud.models.requests.get_borders_request import GetBordersRequest
from asposewordscloud.models.requests.get_borders_online_request import GetBordersOnlineRequest
from asposewordscloud.models.requests.get_comment_request import GetCommentRequest
from asposewordscloud.models.requests.get_comment_online_request import GetCommentOnlineRequest
from asposewordscloud.models.requests.get_comments_request import GetCommentsRequest
from asposewordscloud.models.requests.get_comments_online_request import GetCommentsOnlineRequest
from asposewordscloud.models.requests.get_document_request import GetDocumentRequest
from asposewordscloud.models.requests.get_document_drawing_object_by_index_request import GetDocumentDrawingObjectByIndexRequest
from asposewordscloud.models.requests.get_document_drawing_object_by_index_online_request import GetDocumentDrawingObjectByIndexOnlineRequest
from asposewordscloud.models.requests.get_document_drawing_object_image_data_request import GetDocumentDrawingObjectImageDataRequest
from asposewordscloud.models.requests.get_document_drawing_object_image_data_online_request import GetDocumentDrawingObjectImageDataOnlineRequest
from asposewordscloud.models.requests.get_document_drawing_object_ole_data_request import GetDocumentDrawingObjectOleDataRequest
from asposewordscloud.models.requests.get_document_drawing_object_ole_data_online_request import GetDocumentDrawingObjectOleDataOnlineRequest
from asposewordscloud.models.requests.get_document_drawing_objects_request import GetDocumentDrawingObjectsRequest
from asposewordscloud.models.requests.get_document_drawing_objects_online_request import GetDocumentDrawingObjectsOnlineRequest
from asposewordscloud.models.requests.get_document_field_names_request import GetDocumentFieldNamesRequest
from asposewordscloud.models.requests.get_document_field_names_online_request import GetDocumentFieldNamesOnlineRequest
from asposewordscloud.models.requests.get_document_hyperlink_by_index_request import GetDocumentHyperlinkByIndexRequest
from asposewordscloud.models.requests.get_document_hyperlink_by_index_online_request import GetDocumentHyperlinkByIndexOnlineRequest
from asposewordscloud.models.requests.get_document_hyperlinks_request import GetDocumentHyperlinksRequest
from asposewordscloud.models.requests.get_document_hyperlinks_online_request import GetDocumentHyperlinksOnlineRequest
from asposewordscloud.models.requests.get_document_properties_request import GetDocumentPropertiesRequest
from asposewordscloud.models.requests.get_document_properties_online_request import GetDocumentPropertiesOnlineRequest
from asposewordscloud.models.requests.get_document_property_request import GetDocumentPropertyRequest
from asposewordscloud.models.requests.get_document_property_online_request import GetDocumentPropertyOnlineRequest
from asposewordscloud.models.requests.get_document_protection_request import GetDocumentProtectionRequest
from asposewordscloud.models.requests.get_document_protection_online_request import GetDocumentProtectionOnlineRequest
from asposewordscloud.models.requests.get_document_statistics_request import GetDocumentStatisticsRequest
from asposewordscloud.models.requests.get_document_statistics_online_request import GetDocumentStatisticsOnlineRequest
from asposewordscloud.models.requests.get_document_with_format_request import GetDocumentWithFormatRequest
from asposewordscloud.models.requests.get_field_request import GetFieldRequest
from asposewordscloud.models.requests.get_field_online_request import GetFieldOnlineRequest
from asposewordscloud.models.requests.get_fields_request import GetFieldsRequest
from asposewordscloud.models.requests.get_fields_online_request import GetFieldsOnlineRequest
from asposewordscloud.models.requests.get_files_list_request import GetFilesListRequest
from asposewordscloud.models.requests.get_footnote_request import GetFootnoteRequest
from asposewordscloud.models.requests.get_footnote_online_request import GetFootnoteOnlineRequest
from asposewordscloud.models.requests.get_footnotes_request import GetFootnotesRequest
from asposewordscloud.models.requests.get_footnotes_online_request import GetFootnotesOnlineRequest
from asposewordscloud.models.requests.get_form_field_request import GetFormFieldRequest
from asposewordscloud.models.requests.get_form_field_online_request import GetFormFieldOnlineRequest
from asposewordscloud.models.requests.get_form_fields_request import GetFormFieldsRequest
from asposewordscloud.models.requests.get_form_fields_online_request import GetFormFieldsOnlineRequest
from asposewordscloud.models.requests.get_header_footer_request import GetHeaderFooterRequest
from asposewordscloud.models.requests.get_header_footer_of_section_request import GetHeaderFooterOfSectionRequest
from asposewordscloud.models.requests.get_header_footer_of_section_online_request import GetHeaderFooterOfSectionOnlineRequest
from asposewordscloud.models.requests.get_header_footer_online_request import GetHeaderFooterOnlineRequest
from asposewordscloud.models.requests.get_header_footers_request import GetHeaderFootersRequest
from asposewordscloud.models.requests.get_header_footers_online_request import GetHeaderFootersOnlineRequest
from asposewordscloud.models.requests.get_list_request import GetListRequest
from asposewordscloud.models.requests.get_list_online_request import GetListOnlineRequest
from asposewordscloud.models.requests.get_lists_request import GetListsRequest
from asposewordscloud.models.requests.get_lists_online_request import GetListsOnlineRequest
from asposewordscloud.models.requests.get_office_math_object_request import GetOfficeMathObjectRequest
from asposewordscloud.models.requests.get_office_math_object_online_request import GetOfficeMathObjectOnlineRequest
from asposewordscloud.models.requests.get_office_math_objects_request import GetOfficeMathObjectsRequest
from asposewordscloud.models.requests.get_office_math_objects_online_request import GetOfficeMathObjectsOnlineRequest
from asposewordscloud.models.requests.get_paragraph_request import GetParagraphRequest
from asposewordscloud.models.requests.get_paragraph_format_request import GetParagraphFormatRequest
from asposewordscloud.models.requests.get_paragraph_format_online_request import GetParagraphFormatOnlineRequest
from asposewordscloud.models.requests.get_paragraph_list_format_request import GetParagraphListFormatRequest
from asposewordscloud.models.requests.get_paragraph_list_format_online_request import GetParagraphListFormatOnlineRequest
from asposewordscloud.models.requests.get_paragraph_online_request import GetParagraphOnlineRequest
from asposewordscloud.models.requests.get_paragraphs_request import GetParagraphsRequest
from asposewordscloud.models.requests.get_paragraphs_online_request import GetParagraphsOnlineRequest
from asposewordscloud.models.requests.get_paragraph_tab_stops_request import GetParagraphTabStopsRequest
from asposewordscloud.models.requests.get_paragraph_tab_stops_online_request import GetParagraphTabStopsOnlineRequest
from asposewordscloud.models.requests.get_range_text_request import GetRangeTextRequest
from asposewordscloud.models.requests.get_range_text_online_request import GetRangeTextOnlineRequest
from asposewordscloud.models.requests.get_run_request import GetRunRequest
from asposewordscloud.models.requests.get_run_font_request import GetRunFontRequest
from asposewordscloud.models.requests.get_run_font_online_request import GetRunFontOnlineRequest
from asposewordscloud.models.requests.get_run_online_request import GetRunOnlineRequest
from asposewordscloud.models.requests.get_runs_request import GetRunsRequest
from asposewordscloud.models.requests.get_runs_online_request import GetRunsOnlineRequest
from asposewordscloud.models.requests.get_section_request import GetSectionRequest
from asposewordscloud.models.requests.get_section_online_request import GetSectionOnlineRequest
from asposewordscloud.models.requests.get_section_page_setup_request import GetSectionPageSetupRequest
from asposewordscloud.models.requests.get_section_page_setup_online_request import GetSectionPageSetupOnlineRequest
from asposewordscloud.models.requests.get_sections_request import GetSectionsRequest
from asposewordscloud.models.requests.get_sections_online_request import GetSectionsOnlineRequest
from asposewordscloud.models.requests.get_style_request import GetStyleRequest
from asposewordscloud.models.requests.get_style_from_document_element_request import GetStyleFromDocumentElementRequest
from asposewordscloud.models.requests.get_style_from_document_element_online_request import GetStyleFromDocumentElementOnlineRequest
from asposewordscloud.models.requests.get_style_online_request import GetStyleOnlineRequest
from asposewordscloud.models.requests.get_styles_request import GetStylesRequest
from asposewordscloud.models.requests.get_styles_online_request import GetStylesOnlineRequest
from asposewordscloud.models.requests.get_table_request import GetTableRequest
from asposewordscloud.models.requests.get_table_cell_request import GetTableCellRequest
from asposewordscloud.models.requests.get_table_cell_format_request import GetTableCellFormatRequest
from asposewordscloud.models.requests.get_table_cell_format_online_request import GetTableCellFormatOnlineRequest
from asposewordscloud.models.requests.get_table_cell_online_request import GetTableCellOnlineRequest
from asposewordscloud.models.requests.get_table_online_request import GetTableOnlineRequest
from asposewordscloud.models.requests.get_table_properties_request import GetTablePropertiesRequest
from asposewordscloud.models.requests.get_table_properties_online_request import GetTablePropertiesOnlineRequest
from asposewordscloud.models.requests.get_table_row_request import GetTableRowRequest
from asposewordscloud.models.requests.get_table_row_format_request import GetTableRowFormatRequest
from asposewordscloud.models.requests.get_table_row_format_online_request import GetTableRowFormatOnlineRequest
from asposewordscloud.models.requests.get_table_row_online_request import GetTableRowOnlineRequest
from asposewordscloud.models.requests.get_tables_request import GetTablesRequest
from asposewordscloud.models.requests.get_tables_online_request import GetTablesOnlineRequest
from asposewordscloud.models.requests.insert_comment_request import InsertCommentRequest
from asposewordscloud.models.requests.insert_comment_online_request import InsertCommentOnlineRequest
from asposewordscloud.models.requests.insert_drawing_object_request import InsertDrawingObjectRequest
from asposewordscloud.models.requests.insert_drawing_object_online_request import InsertDrawingObjectOnlineRequest
from asposewordscloud.models.requests.insert_field_request import InsertFieldRequest
from asposewordscloud.models.requests.insert_field_online_request import InsertFieldOnlineRequest
from asposewordscloud.models.requests.insert_footnote_request import InsertFootnoteRequest
from asposewordscloud.models.requests.insert_footnote_online_request import InsertFootnoteOnlineRequest
from asposewordscloud.models.requests.insert_form_field_request import InsertFormFieldRequest
from asposewordscloud.models.requests.insert_form_field_online_request import InsertFormFieldOnlineRequest
from asposewordscloud.models.requests.insert_header_footer_request import InsertHeaderFooterRequest
from asposewordscloud.models.requests.insert_header_footer_online_request import InsertHeaderFooterOnlineRequest
from asposewordscloud.models.requests.insert_list_request import InsertListRequest
from asposewordscloud.models.requests.insert_list_online_request import InsertListOnlineRequest
from asposewordscloud.models.requests.insert_or_update_paragraph_tab_stop_request import InsertOrUpdateParagraphTabStopRequest
from asposewordscloud.models.requests.insert_or_update_paragraph_tab_stop_online_request import InsertOrUpdateParagraphTabStopOnlineRequest
from asposewordscloud.models.requests.insert_page_numbers_request import InsertPageNumbersRequest
from asposewordscloud.models.requests.insert_page_numbers_online_request import InsertPageNumbersOnlineRequest
from asposewordscloud.models.requests.insert_paragraph_request import InsertParagraphRequest
from asposewordscloud.models.requests.insert_paragraph_online_request import InsertParagraphOnlineRequest
from asposewordscloud.models.requests.insert_run_request import InsertRunRequest
from asposewordscloud.models.requests.insert_run_online_request import InsertRunOnlineRequest
from asposewordscloud.models.requests.insert_style_request import InsertStyleRequest
from asposewordscloud.models.requests.insert_style_online_request import InsertStyleOnlineRequest
from asposewordscloud.models.requests.insert_table_request import InsertTableRequest
from asposewordscloud.models.requests.insert_table_cell_request import InsertTableCellRequest
from asposewordscloud.models.requests.insert_table_cell_online_request import InsertTableCellOnlineRequest
from asposewordscloud.models.requests.insert_table_online_request import InsertTableOnlineRequest
from asposewordscloud.models.requests.insert_table_row_request import InsertTableRowRequest
from asposewordscloud.models.requests.insert_table_row_online_request import InsertTableRowOnlineRequest
from asposewordscloud.models.requests.insert_watermark_image_request import InsertWatermarkImageRequest
from asposewordscloud.models.requests.insert_watermark_image_online_request import InsertWatermarkImageOnlineRequest
from asposewordscloud.models.requests.insert_watermark_text_request import InsertWatermarkTextRequest
from asposewordscloud.models.requests.insert_watermark_text_online_request import InsertWatermarkTextOnlineRequest
from asposewordscloud.models.requests.load_web_document_request import LoadWebDocumentRequest
from asposewordscloud.models.requests.move_file_request import MoveFileRequest
from asposewordscloud.models.requests.move_folder_request import MoveFolderRequest
from asposewordscloud.models.requests.optimize_document_request import OptimizeDocumentRequest
from asposewordscloud.models.requests.optimize_document_online_request import OptimizeDocumentOnlineRequest
from asposewordscloud.models.requests.protect_document_request import ProtectDocumentRequest
from asposewordscloud.models.requests.protect_document_online_request import ProtectDocumentOnlineRequest
from asposewordscloud.models.requests.reject_all_revisions_request import RejectAllRevisionsRequest
from asposewordscloud.models.requests.reject_all_revisions_online_request import RejectAllRevisionsOnlineRequest
from asposewordscloud.models.requests.remove_range_request import RemoveRangeRequest
from asposewordscloud.models.requests.remove_range_online_request import RemoveRangeOnlineRequest
from asposewordscloud.models.requests.render_drawing_object_request import RenderDrawingObjectRequest
from asposewordscloud.models.requests.render_drawing_object_online_request import RenderDrawingObjectOnlineRequest
from asposewordscloud.models.requests.render_math_object_request import RenderMathObjectRequest
from asposewordscloud.models.requests.render_math_object_online_request import RenderMathObjectOnlineRequest
from asposewordscloud.models.requests.render_page_request import RenderPageRequest
from asposewordscloud.models.requests.render_page_online_request import RenderPageOnlineRequest
from asposewordscloud.models.requests.render_paragraph_request import RenderParagraphRequest
from asposewordscloud.models.requests.render_paragraph_online_request import RenderParagraphOnlineRequest
from asposewordscloud.models.requests.render_table_request import RenderTableRequest
from asposewordscloud.models.requests.render_table_online_request import RenderTableOnlineRequest
from asposewordscloud.models.requests.replace_text_request import ReplaceTextRequest
from asposewordscloud.models.requests.replace_text_online_request import ReplaceTextOnlineRequest
from asposewordscloud.models.requests.replace_with_text_request import ReplaceWithTextRequest
from asposewordscloud.models.requests.replace_with_text_online_request import ReplaceWithTextOnlineRequest
from asposewordscloud.models.requests.reset_cache_request import ResetCacheRequest
from asposewordscloud.models.requests.save_as_request import SaveAsRequest
from asposewordscloud.models.requests.save_as_online_request import SaveAsOnlineRequest
from asposewordscloud.models.requests.save_as_range_request import SaveAsRangeRequest
from asposewordscloud.models.requests.save_as_range_online_request import SaveAsRangeOnlineRequest
from asposewordscloud.models.requests.save_as_tiff_request import SaveAsTiffRequest
from asposewordscloud.models.requests.save_as_tiff_online_request import SaveAsTiffOnlineRequest
from asposewordscloud.models.requests.search_request import SearchRequest
from asposewordscloud.models.requests.search_online_request import SearchOnlineRequest
from asposewordscloud.models.requests.split_document_request import SplitDocumentRequest
from asposewordscloud.models.requests.split_document_online_request import SplitDocumentOnlineRequest
from asposewordscloud.models.requests.unprotect_document_request import UnprotectDocumentRequest
from asposewordscloud.models.requests.unprotect_document_online_request import UnprotectDocumentOnlineRequest
from asposewordscloud.models.requests.update_bookmark_request import UpdateBookmarkRequest
from asposewordscloud.models.requests.update_bookmark_online_request import UpdateBookmarkOnlineRequest
from asposewordscloud.models.requests.update_border_request import UpdateBorderRequest
from asposewordscloud.models.requests.update_border_online_request import UpdateBorderOnlineRequest
from asposewordscloud.models.requests.update_comment_request import UpdateCommentRequest
from asposewordscloud.models.requests.update_comment_online_request import UpdateCommentOnlineRequest
from asposewordscloud.models.requests.update_drawing_object_request import UpdateDrawingObjectRequest
from asposewordscloud.models.requests.update_drawing_object_online_request import UpdateDrawingObjectOnlineRequest
from asposewordscloud.models.requests.update_field_request import UpdateFieldRequest
from asposewordscloud.models.requests.update_field_online_request import UpdateFieldOnlineRequest
from asposewordscloud.models.requests.update_fields_request import UpdateFieldsRequest
from asposewordscloud.models.requests.update_fields_online_request import UpdateFieldsOnlineRequest
from asposewordscloud.models.requests.update_footnote_request import UpdateFootnoteRequest
from asposewordscloud.models.requests.update_footnote_online_request import UpdateFootnoteOnlineRequest
from asposewordscloud.models.requests.update_form_field_request import UpdateFormFieldRequest
from asposewordscloud.models.requests.update_form_field_online_request import UpdateFormFieldOnlineRequest
from asposewordscloud.models.requests.update_list_request import UpdateListRequest
from asposewordscloud.models.requests.update_list_level_request import UpdateListLevelRequest
from asposewordscloud.models.requests.update_list_level_online_request import UpdateListLevelOnlineRequest
from asposewordscloud.models.requests.update_list_online_request import UpdateListOnlineRequest
from asposewordscloud.models.requests.update_paragraph_format_request import UpdateParagraphFormatRequest
from asposewordscloud.models.requests.update_paragraph_format_online_request import UpdateParagraphFormatOnlineRequest
from asposewordscloud.models.requests.update_paragraph_list_format_request import UpdateParagraphListFormatRequest
from asposewordscloud.models.requests.update_paragraph_list_format_online_request import UpdateParagraphListFormatOnlineRequest
from asposewordscloud.models.requests.update_run_request import UpdateRunRequest
from asposewordscloud.models.requests.update_run_font_request import UpdateRunFontRequest
from asposewordscloud.models.requests.update_run_font_online_request import UpdateRunFontOnlineRequest
from asposewordscloud.models.requests.update_run_online_request import UpdateRunOnlineRequest
from asposewordscloud.models.requests.update_section_page_setup_request import UpdateSectionPageSetupRequest
from asposewordscloud.models.requests.update_section_page_setup_online_request import UpdateSectionPageSetupOnlineRequest
from asposewordscloud.models.requests.update_style_request import UpdateStyleRequest
from asposewordscloud.models.requests.update_style_online_request import UpdateStyleOnlineRequest
from asposewordscloud.models.requests.update_table_cell_format_request import UpdateTableCellFormatRequest
from asposewordscloud.models.requests.update_table_cell_format_online_request import UpdateTableCellFormatOnlineRequest
from asposewordscloud.models.requests.update_table_properties_request import UpdateTablePropertiesRequest
from asposewordscloud.models.requests.update_table_properties_online_request import UpdateTablePropertiesOnlineRequest
from asposewordscloud.models.requests.update_table_row_format_request import UpdateTableRowFormatRequest
from asposewordscloud.models.requests.update_table_row_format_online_request import UpdateTableRowFormatOnlineRequest
from asposewordscloud.models.requests.upload_file_request import UploadFileRequest
